RunFinishedOutcome

Enum RunFinishedOutcome 

pub enum RunFinishedOutcome {
    Success,
    Interrupt,
}
Outcome of a run finishing.

Used to indicate whether a run completed successfully or was interrupted for human-in-the-loop interaction.

Variants



Success

Run completed successfully.



Interrupt

Run was interrupted and requires human input to continue.