ThinkingTextMessageContentEvent

Struct ThinkingTextMessageContentEvent 

pub struct ThinkingTextMessageContentEvent {
    pub base: BaseEvent,
    pub delta: String,
}
Event containing a piece of thinking text message content.

This event contains chunks of the agent’s internal thinking process. Unlike regular content events, thinking content doesn’t validate for empty delta as it may represent the start of a stream.

Fields

base: BaseEvent

Common event fields (timestamp, rawEvent).

delta: String

The thinking content delta.

Implementations

Source

impl ThinkingTextMessageContentEvent

pub fn new(delta: impl Into<String>) -> Self

Creates a new ThinkingTextMessageContentEvent.

pub fn with_timestamp(self, timestamp: f64) -> Self

Sets the timestamp for this event.