AG-UI Event Types
This module defines all AG-UI protocol event types including:
- Text message events (start, content, end, chunk)
- Thinking text message events
- Tool call events (start, args, end, result)
- State events (snapshot, delta)
- Run lifecycle events (started, finished, error)
- Step events (started, finished)
- Custom and raw events
Structs
- Activity
Delta Event - Event containing an incremental activity update.
- Activity
Snapshot Event - Event containing a complete activity snapshot.
- Base
Event - Base event structure for all AG-UI protocol events.
- Custom
Event - Event for custom application-specific data.
- Interrupt
Info - Information about a run interrupt.
- Messages
Snapshot Event - Event containing a complete snapshot of all messages.
- RawEvent
- Event containing raw data from the underlying provider.
- RunError
Event - Event indicating that a run has encountered an error.
- RunFinished
Event - Event indicating that a run has finished.
- RunStarted
Event - Event indicating that a run has started.
- State
Delta Event - Event containing incremental state updates as JSON Patch operations.
- State
Snapshot Event - Event containing a complete state snapshot.
- Step
Finished Event - Event indicating that a step has finished.
- Step
Started Event - Event indicating that a step has started.
- Text
Message Chunk Event - Event containing a chunk of text message content.
- Text
Message Content Event - Event containing a piece of text message content.
- Text
Message EndEvent - Event indicating the end of a text message.
- Text
Message Start Event - Event indicating the start of a text message.
- Thinking
EndEvent - Event indicating that a thinking step has ended.
- Thinking
Start Event - Event indicating that a thinking step has started.
- Thinking
Text Message Content Event - Event containing a piece of thinking text message content.
- Thinking
Text Message EndEvent - Event indicating the end of a thinking text message.
- Thinking
Text Message Start Event - Event indicating the start of a thinking text message.
- Tool
Call Args Event - Event containing tool call arguments.
- Tool
Call Chunk Event - Event containing a chunk of tool call content.
- Tool
Call EndEvent - Event indicating the end of a tool call.
- Tool
Call Result Event - Event containing the result of a tool call.
- Tool
Call Start Event - Event indicating the start of a tool call.
Enums
- Event
- Union of all possible events in the Agent User Interaction Protocol.
- Event
Type - Event types for the AG-UI protocol.
- Event
Validation Error - Validation errors for AG-UI protocol events.
- RunFinished
Outcome - Outcome of a run finishing.